import React, { useState, useEffect } from 'react';
import { Input, Button, message } from 'antd';
import './index.css'

const SMS = () => {
    const [phoneNumber, setPhoneNumber] = useState('');
    const [isSending, setIsSending] = useState(false);
    const [countdown, setCountdown] = useState(60);

    useEffect(() => {
        if (countdown > 0 && isSending) {
            const timer = setTimeout(() => {
                setCountdown(countdown - 1);
            }, 1000);
    
            return () => clearTimeout(timer);
        } else {
            setIsSending(false);
        }
    }, [countdown, isSending]);
        
    const handlePhoneNumberChange = (e) => {
        const value = e.target.value;
        setPhoneNumber(value);
    };

    const handleSendCode = (success) => {
        // 发送验证码请求，这里使用setTimeout模拟请求
        setIsSending(true);
        if (success) {
            setCountdown(60);
            message.success('验证码已发送，请注意查收');
        } else {
            setCountdown(5);
            message.error('验证码发送失败，请重试');
        }
    };
    
    const isPhoneNumberValid = (phoneNumber) => {
        // 手机号合法性校验规则，这里简化为必须为11位数字
        return /^\d{11}$/.test(phoneNumber);
    };

    let captcha;

    const getInstance = (instance) => {
        captcha = instance;
    };

    const captchaVerifyCallback = async (captchaVerifyParam) => {
        // 1.向后端发起业务请求，获取验证码验证结果和业务结果
        // const result = await xxxx('http://您的业务请求地址', {
        //     captchaVerifyParam: captchaVerifyParam, // 验证码参数
        //     yourBizParam... // 业务参数
        // });
        // return {
        //  captchaResult: true, // 验证码验证是否通过，boolean类型，必选
        //  bizResult: true, // 业务验证是否通过，boolean类型，可选；若为无业务验证结果的场景，bizResult可以为空
        // }
        console.log(captchaVerifyParam);
        return {
            captchaResult: true,
            bizResult: true,
        }
    }
      // 验证通过后调用
    const onBizResultCallback = (bizResult)  => {
        console.log('onBizResultCallback');
        handleSendCode(bizResult);
    }

    useEffect(() => {
        // 只用初始化一次验证码即可
        window.initAliyunCaptcha({
            SceneId: 'xxxxx', // 场景ID。根据步骤二新建验证场景后，您可以在验证码场景列表，获取该场景的场景ID
            prefix: 'xxxxxx', // 身份标。开通阿里云验证码2.0后，您可以在控制台概览页面的实例基本信息卡片区域，获取身份标
            mode: 'popup', // 验证码模式。popup表示要集成的验证码模式为弹出式。无需修改
            element: '#captcha-element', // 页面上预留的渲染验证码的元素，与原代码中预留的页面元素保持一致。
            button: '#captcha-button', // 触发验证码弹窗的元素。button表示单击登录按钮后，触发captchaVerifyCallback函数。您可以根据实际使用的元素修改element的值
            captchaVerifyCallback: captchaVerifyCallback, // 业务请求(带验证码校验)回调函数，无需修改
            onBizResultCallback: onBizResultCallback, // 业务请求结果回调函数，无需修改
            getInstance: getInstance, // 绑定验证码实例函数，无需修改
            slideStyle: {
                width: 360,
                height: 40,
            }, // 滑块验证码样式，支持自定义宽度和高度，单位为px。其中，width最小值为320 px
            language: 'cn', // 验证码语言类型，支持简体中文（cn）、繁体中文（tw）、英文（en）
        });
        return () => {
            // 必须删除相关元素，否则再次mount多次调用 initAliyunCaptcha 会导致多次回调 captchaVerifyCallback
            document.getElementById('aliyunCaptcha-mask')?.remove();
            document.getElementById('aliyunCaptcha-window-popup')?.remove();
        }
    }, []);

    return (
        <div className="sms">
            <Input
                placeholder="请输入手机号"
                value={phoneNumber}
                onChange={handlePhoneNumberChange}
            />
            {/* 嵌入式可以控制一下验证码是否显示， 加上这个style */}
            <div id="captcha-element" style={{display: isSending ? 'none' : 'initial'}}></div>
            <Input
                placeholder="请输入验证码"
                addonAfter={
                    <Button
                        id="captcha-button"
                        disabled={!isPhoneNumberValid(phoneNumber) || isSending}
                    >
                        {isSending ? `${countdown}秒` : '发送短信验证码'}
                    </Button>
                }
            />
        </div>
    )
}

export default SMS;